#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const app_1 = require("./app");
const path_1 = require("path");
const fs_1 = require("fs");
const commander_1 = __importDefault(require("commander"));
const packageFile = JSON.parse(fs_1.readFileSync(path_1.join(__dirname, '../package.json')).toString());
/**
 * Commander default setup.
 */
commander_1.default
    .version(packageFile.version, '-v, --version')
    .description('AWS lambda automation cli.');
/**
 * Provides the user with the option to create a project.
 */
commander_1.default
    .command('create')
    .option('-a, --application <arg>', 'project parent application name, eg lozzby')
    .option('-n, --name <arg>', 'project service name.')
    .option('-p, --path <arg>', 'directory new lambda project will be created in.')
    .description('creates new aws lambda project.')
    .action(cmd => {
    let dir = process.cwd();
    let app = 'lozzby';
    let service = 'lambda-manager-service';
    if (isStringType(cmd.application) && cmd.application !== '')
        app = cmd.application;
    if (isStringType(cmd.path) && cmd.path !== '')
        dir += `/${cmd.path}`;
    if (isStringType(cmd.name) && cmd.name !== '')
        service = cmd.name;
    app_1.buildLambda(path_1.resolve(dir), service, app)
        .catch(error => console.error(error));
});
/**
 * Provides the user with the option to deploy a project to aws.
 */
commander_1.default
    .command('deploy')
    .option('-s, --stage <arg>', 'stage the lambda should be deployed, eg. prod|dev|test etc.')
    .option('-r, --region <arg>', 'region the lambda should be deployed, eg. eu-west-2.')
    .option('-f, --function <arg>', 'lambda function name. Deploys a single function.')
    .option('--force', 'forces a deployment to take place.')
    .option('-u, --update', 'updates function configuration, e.g. Timeout or Memory Size without deploying code.')
    .description('deploys lambda in current working directory.')
    .action(cmd => {
    let command = 'npm run lint && serverless deploy';
    if (cmd.update !== undefined && cmd.update)
        command += ` function`;
    if (isStringType(cmd.function) && cmd.function !== '')
        command += ` --function ${cmd.function}`;
    else if (cmd.update !== undefined && cmd.update)
        command += ' --function main';
    if (isStringType(cmd.stage) && cmd.stage !== '')
        command += ` --stage ${cmd.stage}`;
    if (isStringType(cmd.region) && cmd.region !== '')
        command += ` --region ${cmd.region}`;
    if (cmd.force !== undefined && cmd.force)
        command += ` --force`;
    app_1.deployLambda(command)
        .catch(error => console.error(error));
});
/**
 * Provides the user with the option to remove a project from aws.
 */
commander_1.default
    .command('remove')
    .description('removes lambda from aws and all it\'s resources.')
    .action(() => app_1.removeLambda('sls remove'));
/**
 * Validates if the given value is a string.
 * @param {any} value value returned from the user command line application.
 */
function isStringType(value) {
    return (typeof value === 'string' || value instanceof String);
}
// allow commander to parse `process.argv`
commander_1.default.parse(process.argv);
